<?php
/**
 * Add color options in Customizer.
 *
 * @package WEN_Associate
 */

if ( ! function_exists( 'wen_associate_color_theme_options_args' ) ) :

	/**
	 * Add theme color options.
	 *
	 * @since 1.0.0
	 *
	 * @param array $args Arguments.
	 * @return array Modified arguments.
	 */
	function wen_associate_color_theme_options_args( $args ) {

		// Create panel.
		$args['panels']['color_settings_panel']['title'] = __( 'Color Options', 'wen-associate-pro' );

		$color_sections = wen_associate_get_color_sections_options();
		$color_fields   = wen_associate_get_color_theme_settings_options();

		// Add sections.
		$pr = 1;
		foreach ( $color_sections as $section_id => $section ) {

			$args['panels']['color_settings_panel']['sections'][ $section_id ] = array(
				'title'             => $section['label'],
				'priority'          => $pr,
				'sanitize_callback' => 'sanitize_hex_color',
			);

			$pr++;

		}

		// Add color fields.
		foreach ( $color_fields as $field_id => $field ) {
			$args['panels']['color_settings_panel']['sections'][ $field['section'] ]['fields'][ $field_id ] = array(
					'title' => $field['label'],
					'type'  => 'color',
			);
		}

		$args['panels']['color_settings_panel']['sections']['section_reset_color_settings'] = array(
			'title' => __( 'Reset Color Settings', 'wen-associate-pro' ),
		);
		$args['panels']['color_settings_panel']['sections']['section_reset_color_settings']['fields']['reset_all_color_settings'] = array(
				'title'             => __( 'Reset Color Settings', 'wen-associate-pro' ),
				'description'       => __( 'Caution: All color settings will be reset to default. Refresh the page after save to view full effects.', 'wen-associate-pro' ),
				'type'              => 'checkbox',
				'transport'         => 'postMessage',
				'sanitize_callback' => 'wen_associate_sanitize_checkbox',
		);

		return $args;

	}

endif;

add_filter( 'wen_associate_theme_options_args', 'wen_associate_color_theme_options_args' );
